:tocdepth: 1

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _changelog:

Changelog
=========

2.13.3 (not yet released)
-------------------------

2.13.2 (November 11th 2019)
---------------------------

* Fixed: added Django autocomplete JS files.
* Fixed: added minified jQuery 3.3.1 file.
* Fixed: added request to `formfield_for_dbfield`.
* Fixed: use safe label with autocompletes.
* Improved: added separate file for documentation URLs.
* Improved: removed Python 2 support.
* Improved: CSS footer and submit-row fixes.
* Improved: CSS field width with inline tabular.

2.13.1 (June 25th 2019)
-----------------------

* First release of Grappelli which is compatible with Django 2.2.
